package Plugins::File;

#use Plugins::File_config;
use Config::General;

my $conf = new Config::General($config::plugins_dir.'/File.conf');
my %cfg = $conf->getall;

$VERSION = 0.9;
$this_pkg = (caller(0))[0];

##################################################################
#  Write to file
##################################################################
sub write_to_file {
    my($file, $stg) = @_;
    $file =~ /\/([^;\&]+)/;
    $file = $1;
    if($stg){
        open(FILE, ">>$file") or die "$0: can not open file $file for appending ($!)\n";
        print FILE AOSICFG::utfize($stg),"\n";
        close(FILE);
    }
}

##################################################################
#   beforeAddUser
##################################################################
sub beforeAddUser{
    my($status_hash, $ldap, $base_dn, $entry_in) = @_;
    my($this_fun, $msg, $code, $file, $key, $panic, $out_panic);
    $this_fun = (caller(0))[3];
    $msg = 'Everything OK!';
    $code = 0;
    $out_panic = 0;

    AOSICFG::write_ws_log("|> $this_fun(in): ldap=$ldap;\nbase_dn=$base_dn;\nentry_in=\n".Plugins::dump_entry($entry_in)) if $config::aosi_debug_level > 1;
    foreach $key(keys %$status_hash){
        $panic = $status_hash->{$key}->{'before'}->{'panic'};
        AOSICFG::write_ws_log("|> $this_fun(before hash): $key; panic=$panic;") if $config::aosi_debug_level > 2;
    }
    $file = $cfg{'path'}.'/'.$this_fun.'.txt';
    AOSICFG::write_ws_log("|> $this_fun writting to file: $file") if $config::aosi_debug_level > 2;
    write_to_file($file, "ldap=$ldap;\nbase_dn=$base_dn;\nin=\n".Plugins::dump_entry($entry_in)."\ncode=$code\nmsg=$msg\npanic=$out_panic");
    AOSICFG::write_ws_log("|> $this_fun(out): code=$code;msg=$msg;panic=$out_panic;") if $config::aosi_debug_level > 1;
    return $code, $msg, $out_panic;
}

##################################################################
#   afterAddUser
##################################################################
sub afterAddUser{
    my($status_hash, $entry_in, $out_xml) = @_;
    my($this_fun, $file, $msg, $code, $out_panic);
    $this_fun = (caller(0))[3];
    $msg = '';
    $code = 0;
    $out_panic = 0;

    AOSICFG::write_ws_log("|> $this_fun(in): \nentry_in=\n".Plugins::dump_entry($entry_in)."\nout_xml=\n".$out_xml) if $config::aosi_debug_level > 1;
    foreach $key(keys %$status_hash){
        $panic = $status_hash->{$key}->{'before'}->{'panic'};
        AOSICFG::write_ws_log("|> $this_fun(before hash): $key; panic=$panic;") if $config::aosi_debug_level > 2;
    }
    foreach $key(keys %$status_hash){
        $panic = $status_hash->{$key}->{'after'}->{'panic'};
        AOSICFG::write_ws_log("|> $this_fun(after hash): $key; panic=$panic;") if $config::aosi_debug_level > 2;
    }
    $file = $cfg{'path'}.'/'.$this_fun.'.txt';
    AOSICFG::write_ws_log("|> $this_fun writting to file: $file") if $config::aosi_debug_level > 2;
    write_to_file($file, "in=\n".Plugins::dump_entry($entry_in)."\nout=\n".$out_xml);
    AOSICFG::write_ws_log("|> $this_fun(out): code=$code;msg=$msg;panic=$out_panic;") if $config::aosi_debug_level > 1;
    return $code, $msg, $out_panic;
}

##################################################################
#   beforeDeleteUser
##################################################################
sub beforeDeleteUser{
    my($status_hash, $ldap, $base_dn, $entry_in) = @_;
    my($this_fun, $msg, $dn, $code, $file, $panic, $out_panic);
    $this_fun = (caller(0))[3];
    $msg = '';
    $code = 0;
    $out_panic = 0;

    AOSICFG::write_ws_log("|> $this_fun(in): ldap=$ldap;\nbase_dn=$base_dn;\nentry_in=\n".Plugins::dump_entry($entry_in)) if $config::aosi_debug_level > 1;
    foreach $key(keys %$status_hash){
        $panic = $status_hash->{$key}->{'before'}->{'panic'};
        AOSICFG::write_ws_log("|> $this_fun(before hash): $key; panic=$panic;") if $config::aosi_debug_level > 2;
    }
    $file = $cfg{'path'}.'/'.$this_fun.'.txt';
    $dn = $entry_in->{'dn'};
    if($dn eq 'uid=ccctest,dc=inter4,dc=hr'){
        #$msg = 'User '.$dn.' cannot be deleted!';
        #$code = -10101;
    }
    AOSICFG::write_ws_log("|> $this_fun writting to file: $file") if $config::aosi_debug_level > 2;
    write_to_file($file, "ldap=$ldap;\nbase_dn=$base_dn;\nin=\n".Plugins::dump_entry($entry_in)."\ncode=$code\nmsg=$msg\npanic=$out_panic");
    AOSICFG::write_ws_log("|> $this_fun(out): code=$code;msg=$msg;panic=$out_panic;") if $config::aosi_debug_level > 1;
    return $code, $msg, $out_panic;
}

##################################################################
#   afterDeleteUser
##################################################################
sub afterDeleteUser{
    my($status_hash, $entry_in, $out_xml) = @_;
    my($this_fun, $file, $msg, $code, $panic, $out_panic);
    $this_fun = (caller(0))[3];
    $msg = '';
    $code = 0;
    $out_panic = 0;

    AOSICFG::write_ws_log("|> $this_fun(in): \nentry_in=\n".Plugins::dump_entry($entry_in)."\nout_xml=\n".$out_xml) if $config::aosi_debug_level > 1;
    foreach $key(keys %$status_hash){
        $panic = $status_hash->{$key}->{'before'}->{'panic'};
        AOSICFG::write_ws_log("|> $this_fun(before hash): $key; panic=$panic;") if $config::aosi_debug_level > 2;
    }
    foreach $key(keys %$status_hash){
        $panic = $status_hash->{$key}->{'after'}->{'panic'};
        AOSICFG::write_ws_log("|> $this_fun(after hash): $key; panic=$panic;") if $config::aosi_debug_level > 2;
    }
    $file = $cfg{'path'}.'/'.$this_fun.'.txt';
    AOSICFG::write_ws_log("|> $this_fun writting to file: $file") if $config::aosi_debug_level > 2;
    write_to_file($file, "in=\n".Plugins::dump_entry($entry_in)."\nout=\n".$out_xml);
    AOSICFG::write_ws_log("|> $this_fun(out): code=$code;msg=$msg;panic=$out_panic;") if $config::aosi_debug_level > 1;
    return $code, $msg, $out_panic;
}

##################################################################
#   before*Attribute
##################################################################
# Same function for all actions
# 1 = beforeAddAttribute
# 2 = beforeModifyAttribute
# 3 = beforeDeleteAttribute
sub beforeChangeAttribute{
    my($status_hash, $type, $ldap, $base_dn, $entry_in) = @_;
    my($this_fun, $msg, $code, $file, $out_panic);
    $this_fun = (caller(0))[3];
    $msg = '';
    $code = 0;
    $out_panic = 0;

    AOSICFG::write_ws_log("|> $this_fun(in): \ntype=$type;\nldap=$ldap;\nbase_dn=$base_dn;\nentry_in=\n".Plugins::dump_entry($entry_in)) if $config::aosi_debug_level > 1;
    foreach $key(keys %$status_hash){
        $panic = $status_hash->{$key}->{'before'}->{'panic'};
        AOSICFG::write_ws_log("|> $this_fun(before hash): $key; panic=$panic;") if $config::aosi_debug_level > 2;
    }
    $file = $cfg{'path'}.'/'.$this_fun.'.txt';
    AOSICFG::write_ws_log("|> $this_fun writting to file: $file") if $config::aosi_debug_level > 2;
    write_to_file($file, "type=$type;\nldap=$ldap;\nbase_dn=$base_dn;\nin=\n".Plugins::dump_entry($entry_in)."\ncode=$code\nmsg=$msg\npanic=$out_panic");
    AOSICFG::write_ws_log("|> $this_fun(out): code=$code;msg=$msg;panic=$out_panic;") if $config::aosi_debug_level > 1;
    return $code, $msg, $out_panic;
}

##################################################################
#   after*Attribute
##################################################################
# Same function for all actions
# 1 = afterAddAttribute
# 2 = afterModifyAttribute
# 3 = afterDeleteAttribute
sub afterChangeAttribute{
    my($status_hash, $type, $entry_in, $out_xml) = @_;
    my($this_fun, $file, $out_panic);
    $this_fun = (caller(0))[3];
    $msg = '';
    $code = 0;
    $out_panic = 0;

    AOSICFG::write_ws_log("|> $this_fun(in): \ntype=$type;\nentry_in=\n".Plugins::dump_entry($entry_in)."\nout_xml=\n".$out_xml) if $config::aosi_debug_level > 1;
    foreach $key(keys %$status_hash){
        $panic = $status_hash->{$key}->{'before'}->{'panic'};
        AOSICFG::write_ws_log("|> $this_fun(before hash): $key; panic=$panic;") if $config::aosi_debug_level > 2;
    }
    foreach $key(keys %$status_hash){
        $panic = $status_hash->{$key}->{'after'}->{'panic'};
        AOSICFG::write_ws_log("|> $this_fun(after hash): $key; panic=$panic;") if $config::aosi_debug_level > 2;
    }
    $file = $cfg{'path'}.'/'.$this_fun.'.txt';
    AOSICFG::write_ws_log("|> $this_fun writting to file: $file") if $config::aosi_debug_level > 2;
    write_to_file($file, "type=$type;\nin=\n".Plugins::dump_entry($entry_in)."\nout=\n".$out_xml);
    AOSICFG::write_ws_log("|> $this_fun(out): code=$code;msg=$msg;panic=$out_panic;") if $config::aosi_debug_level > 1;
    return $code, $msg, $out_panic;
}


1;
